@@ -347,7 +347,8 @@ static int handle_packet(void)
 			return 1;
 		}
 
-		syslog(LOG_INFO, "attempting to mount entry %s", pkt.name);
+		syslog(LOG_INFO, "attempting to mount entry %s/%s",
+		       ap.path, pkt.name);
 		
 		f = fork();
 		if ( f == -1 ) {
